library(data.table)

# Setup directories
# ------------------------------------------------------

rootDirectory = 'G://' # insert here the link to your data folder
functionDirectory = 'G://'# insert here the link to the function folder
n_loggers = length(dir(rootDirectory))

i_logger = 1
for(i_logger in 1:n_loggers){
  
  inputDirectory = paste(rootDirectory,dir(rootDirectory)[i_logger],'/', sep = '')
  
  setwd(inputDirectory)
  fileList = dir(inputDirectory)[grepl('WLOG',dir(inputDirectory))]
  
  # Load pressure gauge measurement settings
  # ------------------------------------------------------
  p = read.csv(fileList[1], nrows = 1,  header = F)
  samplingFrequency.Hz = as.numeric(unlist(strsplit(as.character(p[1,7]), split = 'F'))[2])
  samplingPeriod.sec = as.numeric(unlist(strsplit(as.character(p[1,8]), split = 'L'))[2])*60
  burstInterval.sec = as.numeric(unlist(strsplit(as.character(p[1,9]), split = 'I'))[2])*60
  
  n_measurements = samplingFrequency.Hz*samplingPeriod.sec
  n_bursts = (length(fileList))*24*60*60/burstInterval.sec
  
  # Read WLOG.csv's and convert to single burst.csv
  # ------------------------------------------------------
  pressure.Pa = array(NA, dim = c(n_measurements,n_bursts))
  temp.C = rep(NA, times = n_bursts)
  dateTime = rep(NA, times = n_bursts) #create a vector fo the same lenght as the number of burst, with empty cells
  previousBursts = 0
  
  i_file = 1
  for(i_file in 1:length(fileList)){
    
    # Load pressure & temperature data
    # ----------------
    
    p = read.csv(fileList[i_file], header = F)[-1,1:12]
    p = data.frame(lapply(p, gsub, pattern='\\+', replacement=''), stringsAsFactors=FALSE)
    
    t = read.csv(fileList[i_file], header = F)[-1,13]
    t = as.numeric(gsub(t, pattern='\\+', replacement=''))
    
    # Find location of burst subheaders
    # ----------------
    headers = which(grepl('Y', p[,1]))
    
    if(length(headers) > 1){
      bursts = 1:length(headers) + previousBursts
      
      # Time stamp
      # ----------------
      year = gsub(p[headers,1], pattern = 'Y', replacement = '20')
      month = gsub(p[headers,2], pattern = 'M', replacement = '')
      day = gsub(p[headers,3], pattern = 'D', replacement = '')
      hour = gsub(p[headers,4], pattern = 'H', replacement = '')
      minute = gsub(p[headers,5], pattern = 'M', replacement = '')
      second = gsub(p[headers,6], pattern = 'S', replacement = '')
      date = paste(year,month,day, sep = '-')
      time = paste(hour,minute,second, sep = ':')
      
      dateTime[bursts] = paste(date, time, sep = ' ')
      
      # Restructure pressure & temp data
      # ----------------
      headers = which(grepl('Y', p[,1]))
      headers = c(headers, dim(p)[1] + 1)
      
      i_header = 1
      for(i_header in 1:(length(headers)- 1)){
        
        start = headers[i_header] + 1
        end = headers[i_header + 1] - 1
        
        temp.C[bursts[i_header]] = mean(t[start:end])
        pressureSeries = as.numeric(t(as.matrix(p[start:end,])))
        pressure.Pa[,bursts[i_header]] = pressureSeries[!is.na(pressureSeries)][1:n_measurements]
      
      }
      previousBursts = previousBursts + length(headers) - 1
      print(paste(i_file,'/',length(fileList)))
    }
  }
  
  removeNABursts = !is.na(colMeans(pressure.Pa))
  pressure.Pa = pressure.Pa[,removeNABursts]
  temp.C = temp.C[removeNABursts]
  dateTime = dateTime[removeNABursts]
  
  write.csv(pressure.Pa, 'pressure.csv', row.names = F)
  #dateTime = as.POSIXct(dateTime)
  d = data.frame(dateTime, temp.C)
  write.csv(d, 'timeStamp.csv', row.names = F)
}


